@@ -239,7 +239,7 @@
 #define ISC_PLATFORM_USETHREADS 1
 
 /*
- * Defined if unistd.h does not cause fd_set to be delared.
+ * Defined if unistd.h does not cause fd_set to be declared.
  */
 #define ISC_PLATFORM_NEEDSYSSELECTH 1
 
@@ -302,7 +302,7 @@
  * If the "xaddq" operation (64bit xadd) is available on this architecture,
  * ISC_PLATFORM_HAVEXADDQ will be defined.
  */
-#define ISC_PLATFORM_HAVEXADDQ 1
+#undef ISC_PLATFORM_HAVEXADDQ
 
 /*
  * If the 32-bit "atomic swap" operation is available on this
@@ -314,7 +314,7 @@
  * If the 64-bit "atomic swap" operation is available on this
  * architecture, ISC_PLATFORM_HAVEATOMICSTORE" will be defined.
  */
-#define ISC_PLATFORM_HAVEATOMICSTOREQ 1
+#undef ISC_PLATFORM_HAVEATOMICSTOREQ
 
 /*
  * If the "compare-and-exchange" operation is available on this architecture,
